@@ -1,3 +1,12 @@
+# RT::Condition::NotStartedInBusinessHours
+#
+# Copyright 2012 synetics GmbH, http://i-doit.org/
+#
+# This program is free software; you can redistribute it and/or modify it under
+# the same terms as Perl itself.
+#
+# Request Tracker (RT) is Copyright Best Practical Solutions, LLC.
+
 package RT::Condition::NotStartedInBusinessHours;
 
 use 5.010;
@@ -11,18 +20,18 @@ use Date::Manip;
 use vars qw/@ISA/;
 @ISA = qw(RT::Condition);
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 
 =head1 NAME
 
-L<RT::Condition::NotStartedInBusinessHours> - Check for unstarted tickets within
+RT::Condition::NotStartedInBusinessHours - Check for unstarted tickets within
 business hours
 
 
 =head1 DESCRIPTION
 
-This RT Condition will check for tickets which are not started within business
+This RT condition will check for tickets which are not started within business
 hours.
 
 
@@ -45,7 +54,7 @@ hours.
 This condition based on the following modules:
 
     RT >= 4.0.0
-    Date::Manip >= 6.25
+    Date::Manip >= 6.34
 
 To install this condition run the following commands:
 
@@ -56,23 +65,30 @@ To install this condition run the following commands:
 
 or place this script under
 
-    RT_HOME/local/lib/RT/Condition/
+    $RT_HOME/local/lib/RT/Condition/
 
-where C<RT_HOME> is the path to your RT installation.
+where C<$RT_HOME> is the path to your RT installation, for example C</opt/rt4>.
 
 You may additionally make this condition available in RT's web UI as a Scrip
 Condition:
 
     make initdb
 
+Another way to install the latest release is via CPAN:
+
+    cpan RT::Condition::NotStartedInBusinessHours
+    $RT_HOME/sbin/rt-setup-database --action insert --datafile /opt/rt4/local/plugins/RT-Condition-NotStartedInBusinessHours/etc/initialdata
+
+The second command is equivalent to C<make initdb>, but is unfortunately not executed automatically.
+
 
 =head1 CONFIGURATION
 
 
 =head2 RT SITE CONFIGURATION
 
-To enabled this condition edit the RT site configuration based in
-C<RT_HOME/etc/RT_SiteConfig>:
+To enabled this condition edit the RT site configuration located under
+C<$RT_HOME/etc/RT_SiteConfig.pm>:
 
     Set(@Plugins,qw(RT::Condition::NotStartedInBusinessHours));
 
@@ -83,11 +99,11 @@ configuration:
         'WorkDayBeg', '9:00',
         'WorkDayEnd', '17:00', 
         #'WorkDay24Hr', '0',
-        #'WorkWeekBeg', '1',
-        #'WorkWeekEnd', '7'
+        'WorkWeekBeg', '1',
+        'WorkWeekEnd', '5'
     ));
 
-For more information see L<http://search.cpan.org/~sbeck/Date-Manip-6.25/lib/Date/Manip/Config.pod#BUSINESS_CONFIGURATION_VARIABLES>.
+For more information see L<http://search.cpan.org/~sbeck/Date-Manip-6.34/lib/Date/Manip/Config.pod#BUSINESS_CONFIGURATION_VARIABLES>.
 
 
 =head2 CONDITION ARGUMENT
@@ -126,22 +142,26 @@ You can also look for information at:
 
 =over 4
 
-=item * Search CPAN
+=item B<Search CPAN>
 
 L<http://search.cpan.org/dist/RT-Condition-NotStartedInBusinessHours/>
 
-=item * RT: CPAN's request tracker
+=item B<RT: CPAN's request tracker>
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=RT-Condition-NotStartedInBusinessHours>
 
-=item * AnnoCPAN: Annotated CPAN documentation
+=item B<AnnoCPAN: Annotated CPAN documentation>
 
 L<http://annocpan.org/dist/RT-Condition-NotStartedInBusinessHours>
 
-=item * CPAN Ratings
+=item B<CPAN Ratings>
 
 L<http://cpanratings.perl.org/d/RT-Condition-NotStartedInBusinessHours>
 
+=item B<Repository>
+
+L<https://github.com/bheisig/rt-condition-notstartedinbusinesshours>
+
 =back
 
 
@@ -149,19 +169,12 @@ L<http://cpanratings.perl.org/d/RT-Condition-NotStartedInBusinessHours>
 
 Please report any bugs or feature requests to the L<author|/"AUTHOR">.
 
-The language setting of the current user (obviously C<root>) has to be set to
-C<en> (English) or left empty (system default is English). Otherwise parsing
-ticket's C<Starts> date by C<Date::Manip> won't work.
-
 
 =head1 ACKNOWLEDGEMENTS
 
 This script is a fork from L<RT::Condition::UntouchedInBusinessHours> written by
 Torsten Brumm.
 
-Special thanks to the synetics GmbH, C<< <http://i-doit.org/> >> for initiating
-and supporting this project!
-
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -185,24 +198,16 @@ Request Tracker (RT) is Copyright Best Practical Solutions, LLC.
 sub IsApplicable {
     my $self = shift;
 
-    ## Enforce English language. Otherwise parsing ticket's 'Starts' date by
-    ## Date::Manip won't work:
-    my $language = substr($self->CurrentUser->Lang, 0, 2);
-    if ($language ne '' && $language ne 'en') {
-        $RT::Logger->error(
-            "This RT condition failed because current user '" .
-            $self->CurrentUser->Name .
-            "' has the unsupported language setting '" .
-            $self->CurrentUser->Lang .
-            "'. It should be set to 'en' (English) or left empty (system default is English)."
-        );
-        return undef;
-    }
-
     ## Fetch ticket information:
     my $ticketObj = $self->TicketObj;
     my $tickid = $ticketObj->Id;
-    my $starts = $ticketObj->StartsObj->AsString;
+
+    ## Calculate starts time (independent from system user's language and date format settings):
+    my $startsObj = new Date::Manip::Date;
+    $startsObj->parse($ticketObj->StartsObj->Get(Format => 'RFC2616'));
+    $startsObj->convert(RT->Config->Get('Timezone'));
+    my $format = '%Y-%m-%d %T %z';
+    my $starts = $startsObj->printf($format);
 
     my $date = new Date::Manip::Date;
 
